# Elasticsearch Configuration
ELASTICSEARCH_HOSTS={es_hosts}
# ELASTICSEARCH_API_KEY=your-api-key-here
# ELASTICSEARCH_USERNAME=your-username
# ELASTICSEARCH_PASSWORD=your-password

# SMF Configuration
SMF_SERVER_NAME={server_name}
SMF_STRUCTURED_LOGGING=true
SMF_METRICS_ENABLED=true
